# JVol

JVol is an experimental image file format and Python library for lossy compression of 3D images using a simplified version of the JPEG algorithm.

Please read the [documentation](https://fepegar.github.io/jvol) to learn more.
